.. _config_reference:

Configuration Reference
============================

This document lists all options for the inmanta server and inmanta agent.

The options are listed per config section.

.. show-options::
    :namespace-files: ./config-namespaces/*.conf

